#!/bin/bash
#
# Copyright (C) 2017-2018  Josu Goikoetxea <josu.goikoetxea@ehu.eus>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

if [ $# -ne 1 ]; then
    echo "Usage: $0 (txt|kb|hyb)"
	exit
fi

ROOT="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
TYPE=$(echo "$1" | tr '[a-z]' '[A-Z]')
METHOD="JOINTC"

echo
echo "JOINTC-$TYPE BILINGUAL EMBEDDINGS' RESULTS (Spearman)"
echo
if [ -e "$ROOT/embeddings/$METHOD-$TYPE-ENES.emb" ]; then
	echo -n '  - ENES  |  ' 
	echo
	perl "$ROOT/similarity.pl" --emb "$ROOT/embeddings/$METHOD-$TYPE-ENES.emb" --ds1 "$ROOT/datasets/WS353enes.tab" --ds2 "$ROOT/datasets/SL999enes.tab" --ds3 "$ROOT/datasets/RGenes.tab" --o1 "$ROOT/WS-$METHOD-$TYPE-ENES.out" --o2 "$ROOT/SL-$METHOD-$TYPE-ENES.out" --o3 "$ROOT/RG-$METHOD-$TYPE-ENES.out"
	echo -n ' 		WS353: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/WS353enes.tab" "$ROOT/WS-$METHOD-$TYPE-ENES.out"
	echo -n ' 		SL999: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/SL999enes.tab" "$ROOT/SL-$METHOD-$TYPE-ENES.out"
	echo -n ' 		RG: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/RGenes.tab" "$ROOT/RG-$METHOD-$TYPE-ENES.out"
	rm "$ROOT/RG-$METHOD-$TYPE-ENES.out"
	rm "$ROOT/WS-$METHOD-$TYPE-ENES.out"
	rm "$ROOT/SL-$METHOD-$TYPE-ENES.out"
fi

if [ -e "$ROOT/embeddings/$METHOD-$TYPE-ENIT.emb" ]; then
	echo -n '  - ENIT  |  ' 
	echo
	perl "$ROOT/similarity.pl" --emb "$ROOT/embeddings/$METHOD-$TYPE-ENIT.emb" --ds1 "$ROOT/datasets/WS353enit.tab" --ds2 "$ROOT/datasets/SL999enit.tab" --o1 "$ROOT/WS-$METHOD-$TYPE-ENIT.out" --o2 "$ROOT/SL-$METHOD-$TYPE-ENIT.out"
	echo -n ' 		WS353: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/WS353enit.tab" "$ROOT/WS-$METHOD-$TYPE-ENIT.out"
	echo -n ' 		SL999: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/SL999enit.tab" "$ROOT/SL-$METHOD-$TYPE-ENIT.out"
	rm "$ROOT/WS-$METHOD-$TYPE-ENIT.out"
	rm "$ROOT/SL-$METHOD-$TYPE-ENIT.out"
fi

if [ -e "$ROOT/embeddings/$METHOD-$TYPE-ESIT.emb" ]; then
	echo -n '  - ESIT  |  ' 
	echo
	perl "$ROOT/similarity.pl" --emb "$ROOT/embeddings/$METHOD-$TYPE-ESIT.emb" --ds1 "$ROOT/datasets/WS353esit.tab" --ds2 "$ROOT/datasets/SL999esit.tab" --o1 "$ROOT/WS-$METHOD-$TYPE-ESIT.out" --o2 "$ROOT/SL-$METHOD-$TYPE-ESIT.out"
	echo -n ' 		WS353: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/WS353esit.tab" "$ROOT/WS-$METHOD-$TYPE-ESIT.out"
	echo -n ' 		SL999: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/SL999esit.tab" "$ROOT/SL-$METHOD-$TYPE-ESIT.out"
	rm "$ROOT/WS-$METHOD-$TYPE-ESIT.out"
	rm "$ROOT/SL-$METHOD-$TYPE-ESIT.out"
fi

if [ -e "$ROOT/embeddings/$METHOD-$TYPE-ENEU.emb" ]; then
	echo -n '  - ENEU  |  ' 
	echo
	perl "$ROOT/similarity.pl" --emb "$ROOT/embeddings/$METHOD-$TYPE-ENEU.emb" --ds1 "$ROOT/datasets/WS353eneu.tab" --ds2 "$ROOT/datasets/RGeneu.tab" --o1 "$ROOT/WS-$METHOD-$TYPE-ENEU.out" --o2 "$ROOT/RG-$METHOD-$TYPE-ENEU.out"
	echo -n ' 		WS353: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/WS353eneu.tab" "$ROOT/WS-$METHOD-$TYPE-ENEU.out"
	echo -n ' 		RG: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/RGeneu.tab" "$ROOT/RG-$METHOD-$TYPE-ENEU.out"
	rm "$ROOT/WS-$METHOD-$TYPE-ENEU.out"
	rm "$ROOT/RG-$METHOD-$TYPE-ENEU.out"
fi

if [ -e "$ROOT/embeddings/$METHOD-$TYPE-ESEU.emb" ]; then
	echo -n '  - ESEU  |  ' 
	echo
	perl "$ROOT/similarity.pl" --emb "$ROOT/embeddings/$METHOD-$TYPE-ESEU.emb" --ds1 "$ROOT/datasets/WS353eseu.tab" --ds2 "$ROOT/datasets/RGeseu.tab" --o1 "$ROOT/WS-$METHOD-$TYPE-ESEU.out" --o2 "$ROOT/RG-$METHOD-$TYPE-ESEU.out"
	echo -n ' 		WS353: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/WS353eseu.tab" "$ROOT/WS-$METHOD-$TYPE-ESEU.out"
	echo -n ' 		RG: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/RGeseu.tab" "$ROOT/RG-$METHOD-$TYPE-ESEU.out"
	rm "$ROOT/WS-$METHOD-$TYPE-ESEU.out"
	rm "$ROOT/RG-$METHOD-$TYPE-ESEU.out"
fi

if [ -e "$ROOT/embeddings/$METHOD-$TYPE-EUIT.emb" ]; then
	echo -n '  - EUIT  |  ' 
	echo
	perl "$ROOT/similarity.pl" --emb "$ROOT/embeddings/$METHOD-$TYPE-EUIT.emb" --ds1 "$ROOT/datasets/WS353euit.tab" --o1 "$ROOT/WS-$METHOD-$TYPE-EUIT.out"
	echo -n ' 		WS353: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/WS353euit.tab" "$ROOT/WS-$METHOD-$TYPE-EUIT.out"
	rm "$ROOT/WS-$METHOD-$TYPE-EUIT.out"
fi
