#!/bin/bash
#
# Copyright (C) 2017-2018  Josu Goikoetxea <josu.goikoetxea@ehu.eus>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

if [ $# -ne 1 ]; then
    echo "Usage: $0 (txt|kb|hyb)"
	exit
fi

ROOT="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
TYPE=$(echo "$1" | tr '[a-z]' '[A-Z]')

echo
echo "MAP-$TYPE BILINGUAL EMBEDDINGS' RESULTS (Spearman)"
echo
if [ -e "$ROOT/embeddings/$TYPE-ES.mapped-to-EN.emb" ]; then
	echo -n '  - ENES' 
	echo
	emb1="$ROOT/embeddings/$TYPE-EN.emb"
	if [ ${TYPE} == "HYB" ]; then
		emb1="$ROOT/embeddings/$TYPE-EN.ENES.emb"
	fi
	perl "$ROOT/similarity-2space.pl" --emb1 ${emb1} --emb2 "$ROOT/embeddings/$TYPE-ES.mapped-to-EN.emb" --ds1 "$ROOT/datasets/WS353enes.tab" --ds2 "$ROOT/datasets/SL999enes.tab" --ds3 "$ROOT/datasets/RGenes.tab" --o1 "$ROOT/WS-MAP-$TYPE-ENES.out" --o2 "$ROOT/SL-MAP-$TYPE-ENES.out" --o3 "$ROOT/RG-MAP-$TYPE-ENES.out"
	echo -n ' 		WS353: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/WS353enes.tab" "$ROOT/WS-MAP-$TYPE-ENES.out"
	echo -n ' 		SL999: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/SL999enes.tab" "$ROOT/SL-MAP-$TYPE-ENES.out"
	echo -n ' 		RG: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/RGenes.tab" "$ROOT/RG-MAP-$TYPE-ENES.out"
	rm "$ROOT/RG-MAP-$TYPE-ENES.out"
	rm "$ROOT/WS-MAP-$TYPE-ENES.out"
	rm "$ROOT/SL-MAP-$TYPE-ENES.out"
fi

if [ -e "$ROOT/embeddings/$TYPE-IT.mapped-to-EN.emb" ]; then
	echo -n '  - ENIT' 
	echo
	emb1="$ROOT/embeddings/$TYPE-EN.emb"
	if [ ${TYPE} == "HYB" ]; then
		emb1="$ROOT/embeddings/$TYPE-EN.ENIT.emb"
	fi
	perl "$ROOT/similarity-2space.pl" --emb1 ${emb1} --emb2 "$ROOT/embeddings/$TYPE-IT.mapped-to-EN.emb" --ds1 "$ROOT/datasets/WS353enit.tab" --ds2 "$ROOT/datasets/SL999enit.tab" --o1 "$ROOT/WS-MAP-$TYPE-ENIT.out" --o2 "$ROOT/SL-MAP-$TYPE-ENIT.out"
	echo -n ' 		WS353: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/WS353enit.tab" "$ROOT/WS-MAP-$TYPE-ENIT.out"
	echo -n ' 		SL999: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/SL999enit.tab" "$ROOT/SL-MAP-$TYPE-ENIT.out"
	rm "$ROOT/WS-MAP-$TYPE-ENIT.out"
	rm "$ROOT/SL-MAP-$TYPE-ENIT.out"
fi

if [ -e "$ROOT/embeddings/$TYPE-IT.mapped-to-ES.emb" ]; then
	echo -n '  - ESIT' 
	echo
	emb1="$ROOT/embeddings/$TYPE-ES.emb"
	if [ ${TYPE} == "HYB" ]; then
		emb1="$ROOT/embeddings/$TYPE-ES.ESIT.emb"
	fi
	perl "$ROOT/similarity-2space.pl" --emb1 ${emb1} --emb2 "$ROOT/embeddings/$TYPE-IT.mapped-to-ES.emb" --ds1 "$ROOT/datasets/WS353esit.tab" --ds2 "$ROOT/datasets/SL999esit.tab" --o1 "$ROOT/WS-MAP-$TYPE-ESIT.out" --o2 "$ROOT/SL-MAP-$TYPE-ESIT.out"
	echo -n ' 		WS353: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/WS353esit.tab" "$ROOT/WS-MAP-$TYPE-ESIT.out"
	echo -n ' 		SL999: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/SL999esit.tab" "$ROOT/SL-MAP-$TYPE-ESIT.out"
	rm "$ROOT/WS-MAP-$TYPE-ESIT.out"
	rm "$ROOT/SL-MAP-$TYPE-ESIT.out"
fi

if [ -e "$ROOT/embeddings/$TYPE-EU.mapped-to-EN.emb" ]; then
	echo -n '  - ENEU' 
	echo
	emb1="$ROOT/embeddings/$TYPE-EN.emb"
	if [ ${TYPE} == "HYB" ]; then
		emb1="$ROOT/embeddings/$TYPE-EN.ENEU.emb"
	fi
	perl "$ROOT/similarity-2space.pl" --emb1 ${emb1} --emb2 "$ROOT/embeddings/$TYPE-EU.mapped-to-EN.emb" --ds1 "$ROOT/datasets/WS353eneu.tab" --ds2 "$ROOT/datasets/RGeneu.tab" --o1 "$ROOT/WS-MAP-$TYPE-ENEU.out" --o2 "$ROOT/RG-MAP-$TYPE-ENEU.out"
	echo -n ' 		WS353: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/WS353eneu.tab" "$ROOT/WS-MAP-$TYPE-ENEU.out"
	echo -n ' 		RG: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/RGeneu.tab" "$ROOT/RG-MAP-$TYPE-ENEU.out"
	rm "$ROOT/WS-MAP-$TYPE-ENEU.out"
	rm "$ROOT/RG-MAP-$TYPE-ENEU.out"
fi

if [ -e "$ROOT/embeddings/$TYPE-EU.mapped-to-ES.emb" ]; then
	echo -n '  - ESEU'  
	echo
	emb1="$ROOT/embeddings/$TYPE-ES.emb"
	if [ ${TYPE} == "HYB" ]; then
		emb1="$ROOT/embeddings/$TYPE-ES.ESEU.emb"
	fi
	perl "$ROOT/similarity-2space.pl" --emb1 ${emb1} --emb2 "$ROOT/embeddings/$TYPE-EU.mapped-to-ES.emb" --ds1 "$ROOT/datasets/WS353eseu.tab" --ds2 "$ROOT/datasets/RGeseu.tab" --o1 "$ROOT/WS-MAP-$TYPE-ESEU.out" --o2 "$ROOT/RG-MAP-$TYPE-ESEU.out"
	echo -n ' 		WS353: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/WS353eseu.tab" "$ROOT/WS-MAP-$TYPE-ESEU.out"
	echo -n ' 		RG: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/RGeseu.tab" "$ROOT/RG-MAP-$TYPE-ESEU.out"
	rm "$ROOT/WS-MAP-$TYPE-ESEU.out"
	rm "$ROOT/RG-MAP-$TYPE-ESEU.out"
fi

if [ -e "$ROOT/embeddings/$TYPE-IT.mapped-to-EU.emb" ]; then
	echo -n '  - EUIT' 
	echo
	perl "$ROOT/similarity-2space.pl" --emb1 "$ROOT/embeddings/$TYPE-EU.emb" --emb2 "$ROOT/embeddings/$TYPE-IT.mapped-to-EU.emb" --ds1 "$ROOT/datasets/WS353euit.tab" --o1 "$ROOT/WS-MAP-$TYPE-EUIT.out"
	echo -n ' 		WS353: '
	perl "$ROOT/correlation.pl" "$ROOT/datasets/WS353euit.tab" "$ROOT/WS-MAP-$TYPE-EUIT.out"
	rm "$ROOT/WS-MAP-$TYPE-EUIT.out"
fi
